@@ -71,19 +71,6 @@ void EditBar::setOpacity(qreal opacity) {
     }
 }
 
-void EditBar::setFocus(bool focus) {
-    Q_D(const EditBar);
-
-    if ((d->complete) && (focus != this->hasFocus())) {
-        if (focus) {
-            this->setFocus(Qt::OtherFocusReason);
-        }
-        else {
-            this->clearFocus();
-        }
-    }
-}
-
 AnchorLine EditBar::left() const {
     Q_D(const EditBar);
 
@@ -125,6 +112,9 @@ void EditBar::changeEvent(QEvent *event) {
     case QEvent::ParentChange:
         emit parentChanged();
         break;
+    case QEvent::EnabledChange:
+        emit enabledChanged();
+        break;
     default:
         break;
     }
