@@ -31,8 +31,12 @@ public:
 
     static void data_append(QDeclarativeListProperty<QObject> *list, QObject *obj);
 
+    static void children_append(QDeclarativeListProperty<QWidget> *list, QWidget *widget);
+
     QDeclarativeListProperty<QObject> data();
 
+    QDeclarativeListProperty<QWidget> children();
+
     void clearGrid();
     void loadGrid();
     void addWidgetToGrid(QWidget *widget);
