@@ -35,8 +35,12 @@ public:
 
     static void data_append(QDeclarativeListProperty<QObject> *list, QObject *obj);
 
+    static void children_append(QDeclarativeListProperty<QWidget> *list, QWidget *widget);
+
     QDeclarativeListProperty<QObject> data();
 
+    QDeclarativeListProperty<QWidget> children();
+
     QHBoxLayout *hbox;
 
     Q_DECLARE_PUBLIC(Row)
