@@ -36,7 +36,7 @@ class ToolBar : public QToolBar, public QDeclarativeParserStatus
     Q_PROPERTY(int width READ width WRITE setFixedWidth NOTIFY widthChanged)
     Q_PROPERTY(int height READ height WRITE setFixedHeight NOTIFY heightChanged)
     Q_PROPERTY(qreal opacity READ opacity WRITE setOpacity NOTIFY opacityChanged)
-    Q_PROPERTY(bool focus READ hasFocus WRITE setFocus NOTIFY focusChanged)
+    Q_PROPERTY(bool enabled READ isEnabled WRITE setEnabled NOTIFY enabledChanged)
     Q_PRIVATE_PROPERTY(ToolBar::d_func(), Anchors* anchors READ anchors CONSTANT FINAL)
     Q_PROPERTY(AnchorLine left READ left CONSTANT FINAL)
     Q_PROPERTY(AnchorLine right READ right CONSTANT FINAL)
@@ -47,6 +47,7 @@ class ToolBar : public QToolBar, public QDeclarativeParserStatus
     Q_PRIVATE_PROPERTY(ToolBar::d_func(), QDeclarativeListProperty<QObject> data READ data)
     Q_PRIVATE_PROPERTY(ToolBar::d_func(), QDeclarativeListProperty<QWidget> children READ children)
     Q_PRIVATE_PROPERTY(ToolBar::d_func(), bool visible READ qmlVisible WRITE setQmlVisible NOTIFY visibleChanged)
+    Q_PRIVATE_PROPERTY(ToolBar::d_func(), bool focus READ hasFocus WRITE setFocus NOTIFY focusChanged)
 
     Q_INTERFACES(QDeclarativeParserStatus)
 
@@ -62,8 +63,6 @@ public:
     qreal opacity() const;
     void setOpacity(qreal opacity);
 
-    void setFocus(bool focus);
-
     AnchorLine left() const;
     AnchorLine right() const;
     AnchorLine top() const;
@@ -79,26 +78,29 @@ signals:
     void heightChanged();
     void opacityChanged();
     void visibleChanged();
+    void enabledChanged();
     void focusChanged();
 
-private:
+protected:
     ToolBar(ToolBarPrivate &dd, QWidget *parent = 0);
 
-    void changeEvent(QEvent *event);
-    void moveEvent(QMoveEvent *event);
-    void resizeEvent(QResizeEvent *event);
-    void showEvent(QShowEvent *event);
-    void hideEvent(QHideEvent *event);
-    void focusInEvent(QFocusEvent *event);
-    void focusOutEvent(QFocusEvent *event);
+    virtual void changeEvent(QEvent *event);
+    virtual void moveEvent(QMoveEvent *event);
+    virtual void resizeEvent(QResizeEvent *event);
+    virtual void showEvent(QShowEvent *event);
+    virtual void hideEvent(QHideEvent *event);
+    virtual void focusInEvent(QFocusEvent *event);
+    virtual void focusOutEvent(QFocusEvent *event);
 
-    void classBegin();
-    void componentComplete();
+    virtual void classBegin();
+    virtual void componentComplete();
 
     QScopedPointer<ToolBarPrivate> d_ptr;
 
-    Q_DISABLE_COPY(ToolBar)
     Q_DECLARE_PRIVATE(ToolBar)
+
+private:
+    Q_DISABLE_COPY(ToolBar)
 };
 
 QML_DECLARE_TYPE(ToolBar)
